@@ -10,7 +10,8 @@ from .. import Unit
 
 class emit(Unit):
 
-    def interface(self, argp):
+    @classmethod
+    def interface(cls, argp):
         argp.add_argument('data', type=multibin, default=None, nargs='*',
             help=(
                 'Data to be emitted. If no argument is specified, data '
@@ -37,6 +38,7 @@ class emit(Unit):
 
     @classmethod
     def run(cls, argv=None, stream=None):
-        super(emit, cls).run(argv=argv,
+        super(emit, cls).run(
+            argv=argv,
             stream=stream or open(__import__('os').devnull, 'rb')
         )
